==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/AccumulationDistributionIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AccumulationDistributionIndicatorDescription } from "./AccumulationDistributionIndicatorDescription";
/**
 * @hidden
 */
export let AccumulationDistributionIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class AccumulationDistributionIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (AccumulationDistributionIndicatorDescriptionMetadata.a == null) {
                AccumulationDistributionIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AccumulationDistributionIndicatorDescriptionMetadata.c(AccumulationDistributionIndicatorDescriptionMetadata.a);
            }
            if (a.j(AccumulationDistributionIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(AccumulationDistributionIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            AccumulationDistributionIndicatorDescriptionMetadata.b(a);
            a.aa("AccumulationDistributionIndicator", () => new AccumulationDistributionIndicatorDescription());
            a.z("AccumulationDistributionIndicator", AccumulationDistributionIndicatorDescriptionMetadata.a);
        }
    }
    AccumulationDistributionIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(AccumulationDistributionIndicatorDescriptionMetadata, 'AccumulationDistributionIndicatorDescriptionMetadata');
    AccumulationDistributionIndicatorDescriptionMetadata.a = null;
    return AccumulationDistributionIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AccumulationDistributionIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AccumulationDistributionIndicatorDescription } from "./AccumulationDistributionIndicatorDescription";
/**
 * @hidden
 */
export let AccumulationDistributionIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class AccumulationDistributionIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (AccumulationDistributionIndicatorDescriptionMetadata.a == null) {
                AccumulationDistributionIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AccumulationDistributionIndicatorDescriptionMetadata.c(AccumulationDistributionIndicatorDescriptionMetadata.a);
            }
            if (a.k(AccumulationDistributionIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(AccumulationDistributionIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            AccumulationDistributionIndicatorDescriptionMetadata.b(a);
            a.ac("AccumulationDistributionIndicator", () => new AccumulationDistributionIndicatorDescription());
            a.ab("AccumulationDistributionIndicator", AccumulationDistributionIndicatorDescriptionMetadata.a);
        }
    }
    AccumulationDistributionIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(AccumulationDistributionIndicatorDescriptionMetadata, 'AccumulationDistributionIndicatorDescriptionMetadata');
    AccumulationDistributionIndicatorDescriptionMetadata.a = null;
    return AccumulationDistributionIndicatorDescriptionMetadata;
})();
